@@ -3,9 +3,9 @@
 
 import logging
 
-__version__ = '0.1.0'
+__version__ = '1.0.0'
 
 try:
     from opencv_engine.engine import Engine  # NOQA
 except ImportError:
-    logging.warning('Could not import opencv_engine. Probably due to setup.py installing it.')
+    logging.exception('Could not import opencv_engine. Probably due to setup.py installing it.')
